S3RequestBuilder

Struct S3RequestBuilder 

pub struct S3RequestBuilder<T: S3ResponseData> { /* private fields */ }
Build and sign an s3 request

Implementations

Source

impl<T> S3RequestBuilder<T>
where T: S3ResponseData,

pub fn new( method: Method, action: &str, access_key: &str, secret_key: &str, region: &str, endpoint: &str, ) -> Self

Create a new S3RequestBuilder

See crate::S3Client::new_request_builder

pub fn method(&mut self, method: Method) -> &mut Self

pub fn action(&mut self, action: &str) -> &mut Self

pub fn query(&mut self, key: &str, value: Option<&str>) -> &mut Self

Add a query string

pub fn header(&mut self, key: &str, value: &str) -> &mut Self

Add a header

pub fn headers(&mut self, headers: Vec<(String, String)>) -> &mut Self

Add a headers

pub fn body<B>(&mut self, body: B) -> &mut Self
where B: AsRef<[u8]>,

Set the request body

pub fn scheme(&mut self, scheme: Scheme) -> &mut Self

Set request scheme

pub fn set_content_headers(&mut self, content: &ContentHeaders) -> &mut Self

Set the request content headers

see ContentHeaders S3RequestBuilder::headers can be easier if adding a small amount of headers

pub fn set_content_query(&mut self, content: &ContentHeaders) -> &mut Self

Set the request content query string will also set the range header if set

see ContentHeaders S3RequestBuilder::query can be easier if adding a small amount of queries

pub fn set_conditional_headers( &mut self, conds: &ConditionalHeaders, ) -> &mut Self

Set the request conditional headers

see ConditionalHeaders S3RequestBuilder::headers can be easier if adding a small amount of headers

pub fn set_x_amz_headers(&mut self, xamz: &XAmzHeaders) -> &mut Self

Set the request x-amz headers

See XAmzHeaders and x_amz_headers::XAmzHeadersBuilder S3RequestBuilder::headers can be easier if adding a small amount of headers

pub fn set_auth( &mut self, access_key: &str, secret_key: &str, region: &str, endpoint: &str, ) -> &mut Self

Set authentication values

pub fn build(&mut self) -> Result<S3Request<T>>

Build and sign the request