pub struct S3RequestBuilder<T: S3ResponseData> { /* private fields */ }Expand description
Build and sign an s3 request
Implementations
Sourceimpl<T> S3RequestBuilder<T>where
T: S3ResponseData,
impl<T> S3RequestBuilder<T>where
T: S3ResponseData,
Sourcepub fn new(
method: Method,
action: &str,
access_key: &str,
secret_key: &str,
region: &str,
endpoint: &str,
) -> Self
pub fn new( method: Method, action: &str, access_key: &str, secret_key: &str, region: &str, endpoint: &str, ) -> Self
Create a new S3RequestBuilder
pub fn method(&mut self, method: Method) -> &mut Self
pub fn action(&mut self, action: &str) -> &mut Self
Sourcepub fn set_content_headers(&mut self, content: &ContentHeaders) -> &mut Self
pub fn set_content_headers(&mut self, content: &ContentHeaders) -> &mut Self
Set the request content headers
see ContentHeaders S3RequestBuilder::headers can be easier if adding a small amount of headers
Sourcepub fn set_content_query(&mut self, content: &ContentHeaders) -> &mut Self
pub fn set_content_query(&mut self, content: &ContentHeaders) -> &mut Self
Set the request content query string will also set the range header if set
see ContentHeaders S3RequestBuilder::query can be easier if adding a small amount of queries
Sourcepub fn set_conditional_headers(
&mut self,
conds: &ConditionalHeaders,
) -> &mut Self
pub fn set_conditional_headers( &mut self, conds: &ConditionalHeaders, ) -> &mut Self
Set the request conditional headers
see ConditionalHeaders S3RequestBuilder::headers can be easier if adding a small amount of headers
Sourcepub fn set_x_amz_headers(&mut self, xamz: &XAmzHeaders) -> &mut Self
pub fn set_x_amz_headers(&mut self, xamz: &XAmzHeaders) -> &mut Self
Set the request x-amz headers
See XAmzHeaders and x_amz_headers::XAmzHeadersBuilder S3RequestBuilder::headers can be easier if adding a small amount of headers